class ClassFolder::ClassFolderSubclass < ClassFolder
  ConstantInClassFolder = 'indeed'
end
